//HypnoHouse 0.3
//Copyright (C) 2005 FollowTheWatch55
//Contact - followthewatch55@yahoo.com

//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.

//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <iostream>
#include <math.h>
#include "tv3dcpp.h"

ITVEngine pEngine;
ITVInputEngine pInput;
ITVGlobals pGlobals;
ITVScene pScene;
ITVAtmosphere pAtmos;
ITVCamera pCamera;
ITVMaterialFactory pMatFactory;
ITVLightEngine pLightEngine;
ITVGraphicEffect pGraphicEffect;
ITVTextureFactory pTextureFactory;
ITVCollisionResult ColRes;

//Meshes
ITVMesh Room;
ITVMesh HypnoRoom;
ITVMesh HypnoDoor;
ITVMesh HypnoChair;
ITVMesh HypnoTV;
ITVMesh HypnoRide;
ITVMesh HypnoRide2;
ITVMesh RideCar;
ITVMesh RideDoor;
ITVMesh HypnoSpiral;
ITVMesh HypnoSpiral2;
ITVMesh HypnoSpiral3;
ITVMesh HypnoSpiral4;
ITVMesh HypnoSpiral5;
ITVMesh HypnoSpiral6;
ITVMesh HypnoSpiral7;
ITVMesh HypnoSpiral8;
ITVMesh HypnoSpiral9;
ITVMesh HypnoSpiral10;
ITVMesh HypnoSpiral11;
ITVMesh Eyes;
ITVMesh BackChair;
ITVMesh Shaft;

void render();
void input();
void unload();

void LoadEnvironment();

float fTimeElapsed = 0.0;

bool isRunning;
bool isFalling;
int gravity;
float FallRate;
long lngOldTick;
float CameraOriginalPos;
int cycle;
bool started;
bool GoCar;
float CarSpeed;

D3DVECTOR linestart;
D3DVECTOR lineend;
D3DVECTOR LineTest;
//D3DLIGHT8 Light[12];

using namespace std;

LRESULT CALLBACK WndProc(HWND wpHWnd, UINT msg, WPARAM wParam, LPARAM lParam);

//WinMain: The entry point to everything Windows
int APIENTRY WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
	HWND WindowHandle;
//	HINSTANCE hInst;
	
	WNDCLASSEX wc = { sizeof(WNDCLASSEX), CS_CLASSDC, WndProc, 0L, 0L,
                      GetModuleHandle(NULL), NULL, NULL, NULL, NULL,
                      "HypnoHouse", NULL };
 	RegisterClassEx(&wc);

	WindowHandle = CreateWindow( "HypnoHouse", "HypnoHouse 0.3",
                              WS_OVERLAPPEDWINDOW, 100, 100, 640, 480,
                              GetDesktopWindow(), NULL, wc.hInstance, NULL );

	// there is a problem creating the window
	if (WindowHandle ==  NULL)
	{
		MessageBox(NULL, "Unable to Create a Window", "Error", MB_OK);
		return false;
	}


 	ShowWindow		(WindowHandle, 1);
 	UpdateWindow	(WindowHandle);
 	SetFocus		(WindowHandle);
 	ShowCursor		(TRUE);

	//Initialze COM
	CoInitialize(NULL);

	pEngine = CreateTVEngine();

	isRunning = true;

	//Engine Running boolean
	double Gamma = 0.0;
	MSG msg;

	//Set the debug file before doing anything else
	pEngine->SetDebugFile ("c:\\debug.txt");
	
	//Initialize Windowed
	pEngine->Init3DWindowedMode ((long)WindowHandle, true);

	//Tell it to display the FPS
	pEngine->put_DisplayFPS(tvtrue);

	//AppPath is a small Macro function in tv3dcpp lib to return the path
	//of a file you pass to it, in this case we get the application path
	char path[256];
	char srchpath[256];
	
	HMODULE Module = (HMODULE)hInstance;
	GetModuleFileName(Module,path,255); 
	
	AppPath(path,srchpath);	
	
	//Set the search directory of the objects, textures, ...
	pEngine->SetSearchDirectory(srchpath);
	
	//We set the AngleSystem to Degrees
	pEngine->SetAngleSystem (TV_ANGLE_DEGREE);

	//Init input after main init, and check if it errors anywhere.
	pInput = CreateTVInputEngine();
	pScene = CreateTVScene();	
	pGlobals = CreateTVGlobals();
	pAtmos = CreateTVAtmosphere();
	pCamera = CreateTVCamera();
	pMatFactory = CreateTVMaterialFactory();
	pLightEngine = CreateTVLightEngine();
	pGraphicEffect = CreateTVGraphicEffect();

	//Create Meshes
	Room = pScene->CreateMeshBuilder ("Room");
	HypnoRoom = pScene->CreateMeshBuilder ("HypnoRoom");
	HypnoDoor = pScene->CreateMeshBuilder ("HypnoDoor");
	HypnoChair = pScene->CreateMeshBuilder ("HypnoChair");
	HypnoTV = pScene->CreateMeshBuilder ("HypnoTV");
	HypnoRide = pScene->CreateMeshBuilder ("HypnoRide");
	HypnoRide2 = pScene->CreateMeshBuilder ("HypnoRide2");
	RideCar = pScene->CreateMeshBuilder ("RideCar");
	RideDoor = pScene->CreateMeshBuilder ("RideDoor");
	HypnoSpiral = pScene->CreateMeshBuilder ("HypnoSpiral");
	HypnoSpiral2 = pScene->CreateMeshBuilder ("HypnoSpiral2");
	HypnoSpiral3 = pScene->CreateMeshBuilder ("HypnoSpiral3");
	HypnoSpiral4 = pScene->CreateMeshBuilder ("HypnoSpiral4");
	HypnoSpiral5 = pScene->CreateMeshBuilder ("HypnoSpiral5");
	HypnoSpiral6 = pScene->CreateMeshBuilder ("HypnoSpiral6");
	HypnoSpiral7 = pScene->CreateMeshBuilder ("HypnoSpiral7");
	HypnoSpiral8 = pScene->CreateMeshBuilder ("HypnoSpiral8");
	HypnoSpiral9 = pScene->CreateMeshBuilder ("HypnoSpiral9");
	HypnoSpiral10 = pScene->CreateMeshBuilder ("HypnoSpiral10");
	HypnoSpiral11 = pScene->CreateMeshBuilder ("HypnoSpiral11");
	Eyes = pScene->CreateMeshBuilder ("Eyes");
	BackChair = pScene->CreateMeshBuilder ("BackChair");
	Shaft = pScene->CreateMeshBuilder ("Shaft");

	//Load the 3D Environment
	LoadEnvironment();

	pCamera->SetPosition (70, 310, 180);
	//pCamera->SetPosition (-160, 10, -125);
	//pCamera->SetPosition (160, 310, 60);
	//pCamera->SetPosition (160, 310, -15030);
	pCamera->SetRotation (0, -143, 0);

    //Set The View distance
    pScene->SetViewFrustum (60, 10000);

	//Fade in
	pGraphicEffect->FadeIn (2000);

	//Main loop	
	while( msg.message!=WM_QUIT)
	{
		if(PeekMessage( &msg, NULL, 0U, 0U, PM_REMOVE ) )
		{
			TranslateMessage( &msg );
			DispatchMessage( &msg );
		}
		else
		{		
			linestart = pCamera->GetPosition();
			Room->SetCollisionEnable (tvtrue, -1);
			HypnoRoom->SetCollisionEnable (tvtrue, -1);
			HypnoDoor->SetCollisionEnable (tvtrue, -1);
			HypnoRide->SetCollisionEnable (tvtrue, -1);

			render();
			input();
		}
	}		

	unload();

	//Exit sucessfully
	return 0;
}

//Render sub
void render()
{
	pEngine->Clear(tvfalse);						//Clear the screen
	pAtmos->Atmosphere_Render();
	pScene->RenderAllMeshes (tvfalse);
	pEngine->RenderToScreen ();					//Render the screen	
}

//Input sub
void input()
{
	if(pInput->IsKeyPressed(TV_KEY_UP))
        pCamera->MoveRelative ((0.015 * pEngine->TimeElapsed()), 0, 0, tvfalse);

    if(pInput->IsKeyPressed(TV_KEY_DOWN))
        pCamera->MoveRelative ((-0.015 * pEngine->TimeElapsed()), 0, 0, tvfalse);

    if(pInput->IsKeyPressed(TV_KEY_LEFT))
        pCamera->RotateY (pEngine->TimeElapsed() * -6 / 100);

    if(pInput->IsKeyPressed(TV_KEY_RIGHT))
        pCamera->RotateY (pEngine->TimeElapsed() * 6 / 100);

	if(pInput->IsKeyPressed(TV_KEY_PAGEUP))
        pCamera->RotateX (-0.68);
    
	if(pInput->IsKeyPressed(TV_KEY_PAGEDOWN))
        pCamera->RotateX (0.68);

	if(pInput->IsKeyPressed(TV_KEY_HOME))
		pCamera->MoveRelative (0, 1, 0, tvfalse);

	if(pInput->IsKeyPressed(TV_KEY_END))
		pCamera->MoveRelative (0, -1, 0, tvfalse);

	if(pInput->IsKeyPressed(TV_KEY_F1))
		pEngine->ScreenShot ("../shot.bmp");

	if(pInput->IsKeyPressed(TV_KEY_A) && RideCar->GetPosition().z > 0)
		GoCar = true;

	if(pInput->IsKeyPressed(TV_KEY_SPACE))
		pCamera->SetRotation (0, 180, 0);
	
	lineend = pCamera->GetPosition();
	LineTest = lineend;

    if(lineend.x > linestart.x)
		LineTest.x = lineend.x + 2;
    if(lineend.x < linestart.x)
		LineTest.x = lineend.x - 2;
    if(lineend.z > linestart.z)
		LineTest.z = lineend.z + 2;
    if(lineend.z < linestart.z)
		LineTest.z = lineend.z - 2;

	/*if (Room->Collision(linestart, LineTest, TV_TESTTYPE_ACCURATETESTING, 0) == tvtrue || HypnoRoom->Collision(linestart, LineTest, TV_TESTTYPE_ACCURATETESTING, 0) == tvtrue || HypnoDoor->Collision(linestart, LineTest, TV_TESTTYPE_ACCURATETESTING, 0) == tvtrue || HypnoRide->Collision(linestart, LineTest, TV_TESTTYPE_ACCURATETESTING, 0) == tvtrue || RideDoor->Collision(linestart, LineTest, TV_TESTTYPE_ACCURATETESTING, 0) == tvrue Or RideCar->Collision(linestart, LineTest, TV_TESTTYPE_ACCURATETESTING, 0) == tvtrue)
		pCamera->SetPosition (linestart.x, linestart.y, linestart.z);
	else
		pCamera->SetPosition (lineend.x, lineend.y, lineend.z);
	*/
	if(pInput->IsKeyPressed(TV_KEY_ESCAPE))		//Check if ESCAPE has been pressed.
	{		
		PostQuitMessage(0);
	}
}

//Unload sub
void unload()
{
	//Uninitialize the variables
	pScene->DestroyAllMeshes ();

	pScene->Release ();
	pInput->Release ();
	pEngine->Release ();
	pAtmos->Release ();
	pCamera->Release ();
	pMatFactory->Release ();
	pLightEngine->Release ();
	pGraphicEffect->Release ();
	pTextureFactory->Release ();

	pScene = NULL;
	pInput = NULL;
	pEngine = NULL;
	pAtmos = NULL;
	pCamera = NULL;
	pMatFactory = NULL;
	pLightEngine = NULL;
	pGraphicEffect = NULL;
	pTextureFactory = NULL;

	Room->Release ();
	HypnoRoom->Release ();
	HypnoDoor->Release ();
	HypnoChair->Release ();
	HypnoTV->Release ();
	HypnoRide->Release ();
	HypnoRide2->Release ();
	RideCar->Release ();
	RideDoor->Release ();
	HypnoSpiral->Release ();
	HypnoSpiral2->Release ();
	HypnoSpiral3->Release ();
	HypnoSpiral4->Release ();
	HypnoSpiral5->Release ();
	HypnoSpiral6->Release ();
	HypnoSpiral7->Release ();
	HypnoSpiral8->Release ();
	HypnoSpiral9->Release ();
	HypnoSpiral10->Release ();
	HypnoSpiral11->Release ();
	Eyes->Release ();
	BackChair->Release ();
	Shaft->Release ();

	Room = NULL;
	HypnoRoom = NULL;
	HypnoDoor = NULL;
	HypnoChair = NULL;
	HypnoTV = NULL;
	HypnoRide = NULL;
	HypnoRide2 = NULL;
	RideCar = NULL;
	RideDoor = NULL;
	HypnoSpiral = NULL;
	HypnoSpiral2 = NULL;
	HypnoSpiral3 = NULL;
	HypnoSpiral4 = NULL;
	HypnoSpiral5 = NULL;
	HypnoSpiral6 = NULL;
	HypnoSpiral7 = NULL;
	HypnoSpiral8 = NULL;
	HypnoSpiral9 = NULL;
	HypnoSpiral10 = NULL;
	HypnoSpiral11 = NULL;
	Eyes = NULL;
	BackChair = NULL;
	Shaft = NULL;

	//Uninitialize COM
	CoUninitialize();
}

LRESULT CALLBACK WndProc(HWND wpHWnd, UINT msg, WPARAM wParam, LPARAM lParam)
{

	switch(msg)
	{	
		case WM_DESTROY: 
		{ 
			PostQuitMessage(0);
			return 0;
		} break;


		default:break; 
	} 


	return DefWindowProc(wpHWnd, msg, wParam, lParam);

} 

void LoadEnvironment()
{
	//Load textures
	pScene->LoadTexture("..\\data\\stone_wall.bmp", -1, -1, "Stone");
    pScene->LoadTexture("..\\data\\rendtexture.bmp", -1, -1, "Floor");
    pScene->LoadTexture("..\\data\\bg54.jpg", -1, -1, "SpiralWall");
    pScene->LoadTexture("..\\data\\bg11.jpg", -1, -1, "BlueTileFloor");
    pScene->LoadTexture("..\\data\\bluefloor.jpg", -1, -1, "BlueFloor");
    pScene->LoadTexture("..\\data\\elegance05.jpg", -1, -1, "EleganceWall");
    pScene->LoadTexture("..\\data\\ff21.jpg", -1, -1, "Ceiling1");
    pScene->LoadTexture("..\\data\\bg14.jpg", -1, -1, "RedTileFloor");
    pScene->LoadTexture("..\\data\\bg4l.jpg", -1, -1, "Purple");
    pScene->LoadTexture("..\\data\\bgc1.jpg", -1, -1, "Blue");
    pScene->LoadTexture("..\\data\\ff09.jpg", -1, -1, "DarkCeiling");
    pScene->LoadTexture("..\\data\\pc8.jpg", -1, -1, "ShaftBlue");
    pScene->LoadTexture("..\\data\\pc9.jpg", -1, -1, "ShaftYellow");
    pScene->LoadTexture("..\\data\\storeleft.jpg", -1, -1, "StoreLeft");
    pScene->LoadTexture("..\\data\\storeright.jpg", -1, -1, "StoreRight");
    pScene->LoadTexture("..\\data\\storetop.jpg", -1, -1, "StoreTop");
    pScene->LoadTexture("..\\data\\road.jpg", -1, -1, "Road");
    pScene->LoadTexture("..\\data\\bluebackwall.jpg", -1, -1, "BlueBackWall");
    pScene->LoadTexture("..\\data\\buildbackwall.jpg", -1, -1, "BuildBackWall");
    pScene->LoadTexture("..\\data\\windows1side.jpg", -1, -1, "windows");
    pScene->LoadTexture("..\\data\\top.jpg", -1, -1, "SkyTop");
    pScene->LoadTexture("..\\data\\bottom.jpg", -1, -1, "SkyBottom");
    pScene->LoadTexture("..\\data\\left.jpg", -1, -1, "SkyLeft");
    pScene->LoadTexture("..\\data\\right.jpg", -1, -1, "SkyRight");
    pScene->LoadTexture("..\\data\\front.jpg", -1, -1, "SkyFront");
    pScene->LoadTexture("..\\data\\back.jpg", -1, -1, "SkyBack");
    pScene->LoadTexture("..\\data\\spiral.jpg", -1, -1, "Spiral");
    pScene->LoadTexture("..\\data\\YellowWhiteSpiral.jpg", -1, -1, "YellowSpiral");
    pScene->LoadTexture("..\\data\\spiral2.jpg", -1, -1, "Spiral2");
    pScene->LoadTexture("..\\data\\hypnotic.jpg", -1, -1, "Hypnotic");
    pScene->LoadTexture("..\\data\\colorspiral.jpg", -1, -1, "ColorSpiral");
    pScene->LoadTexture("..\\data\\hypno+eyes.jpg", -1, -1, "HypnoEyes");
    
    //Create sky
    pAtmos->SkyBox_SetTexture(pGlobals->GetTex("SkyFront"), pGlobals->GetTex("SkyBack"), pGlobals->GetTex("SkyLeft"), pGlobals->GetTex("SkyRight"), pGlobals->GetTex("SkyTop"), pGlobals->GetTex("SkyBottom"));
    pAtmos->SkyBox_Enable(tvtrue, tvtrue);
	
	//Create 3D environment

	//Outside
	Room->AddFloor(pGlobals->GetTex("Road"), -50, 120, 100, 200, 300, 2, 2, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("StoreRight"), 0, 120.1, 25, 120.1, 20, 300, -1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("StoreLeft"), 35, 120.1, 60, 120.1, 20, 300, -1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("StoreTop"), 0, 120.1, 60, 120.1, 15, 320, -1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BuildBackWall"), 10, 120, -50, 120, 30, 300, -1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BuildBackWall"), -50, 160, -50, 200, 30, 300, -1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BlueBackWall"), -50, 120, -50, 160, 30, 300, -1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BuildBackWall"), 50, 120, 100, 120, 30, 300, -1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BuildBackWall"), 100, 160, 100, 200, 30, 300, -1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BlueBackWall"), 100, 120, 100, 160, 30, 300, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("windows"), -50, 200, 100, 200, 120, 300, 2, 1, tvtrue, tvfalse);

	//Front Room
	Room->AddFloor(pGlobals->GetTex("BlueFloor"), 10, 50, 50, 120, 300, 4, 4, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 10, 50, 10, 120, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 50, 50, 50, 90, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 50, 100, 50, 120, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 10, 120, 25, 120, 20, 300, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 35, 120, 50, 120, 20, 300, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 10, 50.1, 30, 50.1, 20, 300, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 40, 50.1, 50, 50.1, 20, 300, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 30, 50.1, 40, 50.1, 2, 318, 1, 0.1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Ceiling1"), 10, 50, 50, 120, 320, 4, 4, tvtrue, tvfalse);
  
	//Left Hall
	Room->AddFloor(pGlobals->GetTex("BlueFloor"), 50, 85, 150, 105, 300, 4, 4, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Ceiling1"), 50, 85, 150, 105, 320, 4, 4, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 50, 85, 150, 85, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 50, 105, 150, 105, 20, 300, 4, 1, tvtrue, tvfalse);
  
	//Left Hall 2
	Room->AddFloor(pGlobals->GetTex("BlueFloor"), 150, 50, 170, 105, 300, 4, 4, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Ceiling1"), 150, 50, 170, 105, 320, 4, 4, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 170, 105, 170, 50, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 150, 85, 150, 50, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 150, 105, 170, 105, 20, 300, 4, 1, tvtrue, tvfalse);
  
	//HypnoRide Room
	Room->AddFloor(pGlobals->GetTex("BlueFloor"), 150, -30, 170, 50, 300, 4, 4, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Ceiling1"), 150, -30, 200, 50, 320, 4, 4, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 200, -30, 200, 50, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 150, -30, 150, 50, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 170, 50, 200, 50, 27, 293, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 150, -30, 170, -30, 20, 300, 4, 1, tvtrue, tvfalse);
  
	RideDoor->AddWall(pGlobals->GetTex("Purple"), 170, -30, 200, -30, 27, 293, 1, 1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Blue"), 170, -30, 200, 50, 293, 4, 4, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 170, -30, 170, 50, 7, 293, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 200, -30, 200, 50, 7, 293, 4, 1, tvtrue, tvfalse);
  
	//HypnoRide Tunnel
	HypnoRide->AddFloor(pGlobals->GetTex("ColorSpiral"), -20, 0, 20, -5000, -20, 1, 5000 / 40, tvtrue, tvfalse);
	HypnoRide->AddFloor(pGlobals->GetTex("ColorSpiral"), -20, 0, 20, -5000, 20, 1, 5000 / 40, tvtrue, tvfalse);
	HypnoRide->AddWall(pGlobals->GetTex("ColorSpiral"), -20, 0, -20, -5000, 40, -20, 5000 / 40, 1, tvtrue, tvfalse);
	HypnoRide->AddWall(pGlobals->GetTex("ColorSpiral"), 20, 0, 20, -5000, 40, -20, 5000 / 40, 1, tvtrue, tvfalse);
  
	//HypnoRide Tunnel 2
	HypnoRide2->AddFloor(pGlobals->GetTex("Spiral2"), -20, 0, 20, -10000, -20, 1, 10000 / 40, tvtrue, tvfalse);
	HypnoRide2->AddFloor(pGlobals->GetTex("Spiral2"), -20, 0, 20, -10000, 20, 1, 10000 / 40, tvtrue, tvfalse);
	HypnoRide2->AddWall(pGlobals->GetTex("Spiral2"), -20, 0, -20, -10000, 40, -20, 10000 / 40, 1, tvtrue, tvfalse);
	HypnoRide2->AddWall(pGlobals->GetTex("Spiral2"), 20, 0, 20, -10000, 40, -20, 10000 / 40, 1, tvtrue, tvfalse);
  
	HypnoRide->SetPosition (185, 307, -30);
  
	HypnoRide2->SetPosition (185, 307, -5000);
  
	//HypnoRide coaster car
	RideCar->AddFloor(pGlobals->GetTex("ShaftYellow"), -13, -20, 13, 20, 0, 2, 2, tvtrue, tvfalse);
	RideCar->SetPosition (185, 300, 20);
  
	//Opposite HypnoRide Room
	Room->AddFloor(pGlobals->GetTex("BlueFloor"), 150, -15000, 170, -15080, 300, 4, 4, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Ceiling1"), 150, -15000, 200, -15080, 320, 4, 4, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 200, -15000, 200, -15080, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 150, -15000, 150, -15080, 20, 300, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 170, -15080, 200, -15080, 27, 293, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 150, -15000, 170, -15000, 20, 300, 4, 1, tvtrue, tvfalse);
  
	RideDoor->AddWall(pGlobals->GetTex("Purple"), 170, -15000, 200, -15000, 27, 293, 1, 1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Blue"), 170, -15000, 200, -15080, 293, 4, 4, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 170, -15000, 170, -15080, 7, 293, 4, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 200, -15000, 200, -15080, 7, 293, 4, 1, tvtrue, tvfalse);

	//Hall after opposite room
	Room->AddFloor(pGlobals->GetTex("BlueFloor"), -50, -15080, 0, -15090, 300, 3, 1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("BlueFloor"), 10, -15080, 170, -15090, 300, 10, 1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Ceiling1"), -50, -15080, 170, -15090, 320, 13, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), 170, -15080, 170, -15090, 20, 300, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), -50, -15080, -50, -15090, 20, 300, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), -50, -15090, 170, -15090, 20, 300, 12, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("EleganceWall"), -50, -15080, 150, -15080, 20, 300, 11, 1, tvtrue, tvfalse);

	//haha
	Room->AddWall(pGlobals->GetTex("BlueFloor"), 0, -15080, 0, -15090, 20, 280, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BlueFloor"), 10, -15080, 10, -15090, 20, 280, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BlueFloor"), 0, -15080, 10, -15080, 20, 280, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("BlueFloor"), 0, -15090, 10, -15090, 20, 280, 1, 1, tvtrue, tvfalse);

	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 0, -15080, 0, -15090, 1000, -720, 2, 100, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 10, -15080, 10, -15090, 1000, -720, 2, 100, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 0, -15080, 10, -15080, 1000, -720, 2, 100, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 0, -15090, 10, -15090, 1000, -720, 2, 100, tvtrue, tvfalse);
	Shaft->AddFloor(pGlobals->GetTex("ShaftYellow"), 0, -15080, 10, -15090, -720, 2, 2, tvtrue, tvfalse);
  
	//Gateway room
	Room->AddFloor(pGlobals->GetTex("Blue"), 10, 20, 20, 50, 300, 2, 2, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("Blue"), 20, 10, 50, 50, 300, 2, 2, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 10, 10, 10, 50, 20, 300, 2, 2, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 50, 10, 50, 50, 20, 300, 2, 2, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 10, 10, 50, 10, 20, 300, 2, 2, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 10, 50, 30, 50, 20, 300, 2, 2, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 40, 50, 50, 50, 20, 300, 2, 2, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("Purple"), 30, 50, 40, 50, 2, 318, 2, 0.2, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("DarkCeiling"), 10, 10, 15, 45, 320, 2, 2, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("DarkCeiling"), 15, 10, 50, 50, 320, 2, 2, tvtrue, tvfalse);
  
	//Shaft
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 10, 10, 10, 20, 280, 20, 2, 30, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 20, 10, 20, 20, 280, 20, 2, 30, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 10, 10, 20, 10, 280, 20, 2, 30, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 10, 20, 20, 20, 280, 20, 2, 30, tvtrue, tvfalse);
  
	//Shaft2
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 10, 45, 10, 50, 40, 320, 2, 4, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 15, 45, 15, 50, 40, 320, 2, 4, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 10, 45, 15, 45, 40, 320, 2, 4, tvtrue, tvfalse);
	Shaft->AddWall(pGlobals->GetTex("ShaftYellow"), 10, 50, 15, 50, 40, 320, 2, 4, tvtrue, tvfalse);
	Shaft->AddFloor(pGlobals->GetTex("ShaftYellow"), 10, 45, 15, 50, 360, 2, 2, tvtrue, tvfalse);
  
	//Basement room
	Room->AddFloor(pGlobals->GetTex("ShaftBlue"), -20, -20, 20, 20, 0, 0.5, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -20, -20, 20, -20, 20, 0, 0.5, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -20, 20, 20, 20, 20, 0, 0.5, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -20, -10, -20, 20, 20, 0, 0.5, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -20, -20, -20, -10, 2, 18, 0.2, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), 20, -20, 20, 20, 20, 0, 0.5, 1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("ShaftBlue"), -20, -20, 20, 10, 20, 0.5, 1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("ShaftBlue"), -20, 10, 10, 20, 20, 0.5, 1, tvtrue, tvfalse);
  
	//Hallway part 1
	Room->AddFloor(pGlobals->GetTex("ShaftBlue"), -150, -20, -20, -10, 0, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -150, -20, -20, -20, 20, 0, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -150, -10, -20, -10, 20, 0, 1, 1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("ShaftBlue"), -150, -20, -20, -10, 20, 1, 1, tvtrue, tvfalse);
  
	//Hallway part 2
	Room->AddFloor(pGlobals->GetTex("ShaftBlue"), -160, -10, -150, -100, 0, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -150, -20, -150, -100, 20, 0, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -160, -10, -160, -100, 20, 0, 1, 1, tvtrue, tvfalse);
	Room->AddWall(pGlobals->GetTex("ShaftBlue"), -160, -10, -150, -10, 20, 0, 1, 1, tvtrue, tvfalse);
	Room->AddFloor(pGlobals->GetTex("ShaftBlue"), -160, -10, -150, -100, 20, 1, 1, tvtrue, tvfalse);
  
	//Hypno Room
	HypnoRoom->AddFloor(pGlobals->GetTex("BlueTileFloor"), -200, -100, -100, -150, 0, 12, 6, tvtrue, tvfalse);
	HypnoRoom->AddWall(pGlobals->GetTex("SpiralWall"), -200, -100, -160, -100, 30, 0, 6, 6, tvtrue, tvfalse);
	HypnoRoom->AddWall(pGlobals->GetTex("SpiralWall"), -150, -100, -100, -100, 30, 0, 6, 6, tvtrue, tvfalse);
	HypnoRoom->AddWall(pGlobals->GetTex("SpiralWall"), -160, -100, -150, -100, 10, 20, 2, 2, tvtrue, tvfalse);
	HypnoDoor->AddWall(pGlobals->GetTex("SpiralWall"), -160, -100.1, -150, -100.1, 20, 0, 2, 4, tvtrue, tvfalse);
	HypnoRoom->AddWall(pGlobals->GetTex("SpiralWall"), -200, -150, -100, -150, 30, 0, 12, 6, tvtrue, tvfalse);
	HypnoRoom->AddWall(pGlobals->GetTex("SpiralWall"), -200, -100, -200, -150, 30, 0, 6, 6, tvtrue, tvfalse);
	HypnoRoom->AddWall(pGlobals->GetTex("SpiralWall"), -100, -100, -100, -150, 30, 0, 6, 6, tvtrue, tvfalse);
	HypnoRoom->AddFloor(pGlobals->GetTex("RedTileFloor"), -200, -100, -100, -150, 30, 12, 6, tvtrue, tvfalse);

	BackChair->Load3DSMesh ("..\\data\\chair11.3ds", tvtrue, tvtrue, tvfalse, tvtrue, tvtrue);
	BackChair->SetPosition (38, 303, 26);
	BackChair->ScaleMesh (0.2, 0.2, 0.2);
	//BackChair->SetRotation (0, 180, 0);

	HypnoChair->Load3DSMesh ("..\\data\\chair12.3ds", tvtrue, tvtrue, tvfalse, tvtrue, tvtrue);
	HypnoChair->SetPosition (-150, 5, -125);
	HypnoChair->ScaleMesh (0.3, 0.3, 0.3);
	HypnoChair->SetRotation (0, 90, 0);

	HypnoTV->Load3DSMesh ("..\\data\\tv.3ds", tvtrue, tvtrue, tvtrue, tvtrue, tvtrue);
	HypnoTV->SetPosition (38, 307, 11);
	HypnoTV->ScaleMesh (0.03, 0.03, 0.03);
	HypnoTV->SetRotation (0, 180, 0);
  
	HypnoSpiral11->SetPosition (38, 305.25, 14);
	HypnoSpiral11->AddWall(pGlobals->GetTex("ColorSpiral"), 0, -3.5, 0, 3.5, 7, -3.5, 1, 1, tvtrue, tvfalse);
	HypnoSpiral11->SetRotation (0, 90, 0);

	HypnoSpiral->Load3DSMesh ("..\\data\\hypnospiral.3ds", tvtrue, tvtrue, tvfalse, tvtrue, tvtrue);
	HypnoSpiral->SetPosition (-199, 13, -125);
	HypnoSpiral->ScaleMesh (0.1, 0.1, 0.1);
	HypnoSpiral->SetRotation (0, 0, 90);
  
	HypnoSpiral2->SetPosition (-199.7, 13.5, -138);
	HypnoSpiral3->SetPosition (-199.7, 13.5, -112);
	HypnoSpiral2->AddWall(pGlobals->GetTex("Spiral"), 0, -5, 0, 5, 10, -5, 1, 1, tvtrue, tvfalse);
	HypnoSpiral3->AddWall(pGlobals->GetTex("Spiral"), 0, -5, 0, 5, 10, -5, 1, 1, tvtrue, tvfalse);
  
	HypnoSpiral4->SetPosition (-199.8, 18, -142);
	HypnoSpiral4->AddWall(pGlobals->GetTex("YellowSpiral"), 0, -5, 0, 5, 10, -5, 1, 1, tvtrue, tvfalse);
  
	HypnoSpiral5->SetPosition (-199.8, 18, -108);
	HypnoSpiral5->AddWall(pGlobals->GetTex("YellowSpiral"), 0, -5, 0, 5, 10, -5, 1, 1, tvtrue, tvfalse);
  
	HypnoSpiral6->SetPosition (-199.9, 13.5, -125);
	HypnoSpiral6->AddWall(pGlobals->GetTex("Spiral2"), 0, -30, 0, 30, 60, -30, 1, 1, tvtrue, tvfalse);
  
	HypnoSpiral7->SetPosition (-185, 15, -100.1);
	HypnoSpiral7->AddWall(pGlobals->GetTex("ColorSpiral"), -15, 0, 15, 0, 30, -15, 1, 1, tvtrue, tvfalse);
  
	HypnoSpiral8->SetPosition (-185, 15, -149.9);
	HypnoSpiral8->AddWall(pGlobals->GetTex("ColorSpiral"), -15, 0, 15, 0, 30, -15, 1, 1, tvtrue, tvfalse);
  
	HypnoSpiral9->SetPosition (-185, 0.1, -125);
	HypnoSpiral9->AddFloor(pGlobals->GetTex("Hypnotic"), -15, -15, 15, 15, 0, 1, 1, tvtrue, tvfalse);
  
	HypnoSpiral10->SetPosition (-185, 29.9, -125);
	HypnoSpiral10->AddFloor(pGlobals->GetTex("Hypnotic"), -15, -15, 15, 15, 0, 1, 1, tvtrue, tvfalse);
  
	Eyes->SetPosition (-195, 23, -125.3);
	Eyes->AddWall(pGlobals->GetTex("HypnoEyes"), 0, -7, 0, 7, 2.5, 0, 1, 1, tvtrue, tvfalse);
  
	pMatFactory->CreateMaterialQuick (0.2, 0.2, 0.2, 1, "QuickMAT");
	pMatFactory->CreateMaterialQuick (1, 1, 1, 1, "QuickMAT2");
	pMatFactory->CreateMaterialQuick (0.05, 0, 0.05, 1, "QuickMAT3");
/*
	Light(1).Type = D3DLIGHT_POINT
	Light(1).Position = Vector3(30, 320, 70)
	Light(1).Ambient = DXColor(1, 1, 1, 1)
	Light(1).diffuse = DXColor(1, 1, 1, 1)
	Light(1).Attenuation0 = 0.5
	Light(1).Range = 60
	LightEngine.CreateLight Light(1), "Light"
	LightEngine.UpdateLight 1, Light(1)

	Light(2).Type = D3DLIGHT_POINT
	Light(2).Position = Vector3(30, 320, 20)
	Light(2).Ambient = DXColor(0, 1, 1, 1)
	Light(2).diffuse = DXColor(1, 1, 1, 1)
	Light(2).Attenuation0 = 0
	Light(2).Range = 30
	LightEngine.CreateLight Light(2), "Light2"
	LightEngine.UpdateLight 2, Light(2)

	Light(3).Type = D3DLIGHT_POINT
	Light(3).Position = Vector3(15, 50, 15)
	Light(3).Ambient = DXColor(1, 1, 0, 1)
	Light(3).diffuse = DXColor(1, 1, 1, 1)
	Light(3).Direction = Vector(0, 30, 0)
	Light(3).Attenuation0 = 0
	Light(3).Range = 170
	LightEngine.CreateLight Light(3), "Light3"
	LightEngine.UpdateLight 3, Light(3)
  
	Light(4).Type = D3DLIGHT_POINT
	Light(4).Position = Vector3(-155, 20, -100)
	Light(4).Ambient = DXColor(0, 1, 1, 1)
	Light(4).diffuse = DXColor(0, 1, 1, 1)
	//Light(4).Direction = Vector(0, 30, 0)
	Light(4).Attenuation0 = 0
	Light(4).Range = 50
	LightEngine.CreateLight Light(4), "Light4"
	LightEngine.UpdateLight 4, Light(4)
  
	Light(5).Type = D3DLIGHT_POINT
	Light(5).Position = Vector3(-150, 30, -125)
	Light(5).Ambient = DXColor(1, 1, 0, 1)
	Light(5).diffuse = DXColor(1, 1, 1, 1)
	Light(5).Direction = Vector(0, 30, 0)
	Light(5).Attenuation0 = 0
	Light(5).Range = 30
	LightEngine.CreateLight Light(5), "Light5"
	LightEngine.UpdateLight 5, Light(5)
  
	Light(6).Type = D3DLIGHT_POINT
	Light(6).Position = Vector3(-200, 0, -150)
	Light(6).Ambient = DXColor(1, 1, 1, 1)
	Light(6).diffuse = DXColor(1, 1, 1, 1)
	Light(6).Direction = Vector(0, 330, 0)
	Light(6).Attenuation0 = 0
	Light(6).Attenuation1 = 0
	Light(6).Attenuation2 = 0
	Light(6).Range = 30
	LightEngine.CreateLight Light(6), "Light6"
	LightEngine.UpdateLight 6, Light(6)

	Light(7).Type = D3DLIGHT_POINT
	Light(7).Position = Vector3(-200, 0, -125)
	Light(7).Ambient = DXColor(1, 1, 0, 1)
	Light(7).diffuse = DXColor(1, 1, 0, 1)
	Light(7).Direction = Vector(0, 330, 0)
	Light(7).Attenuation0 = 0
	Light(7).Attenuation1 = 0
	Light(7).Attenuation2 = 0
	Light(7).Range = 30
	LightEngine.CreateLight Light(7), "Light7"
	LightEngine.UpdateLight 7, Light(7)

	Light(8).Type = D3DLIGHT_POINT
	Light(8).Position = Vector3(-200, 0, -100)
	Light(8).Ambient = DXColor(0, 1, 1, 1)
	Light(8).diffuse = DXColor(0, 1, 1, 1)
	Light(8).Direction = Vector(0, 330, 0)
	Light(8).Attenuation0 = 0
	Light(8).Attenuation1 = 0
	Light(8).Attenuation2 = 0
	Light(8).Range = 30
	LightEngine.CreateLight Light(8), "Light8"
	LightEngine.UpdateLight 8, Light(8)

	Light(9).Type = D3DLIGHT_POINT
	Light(9).Position = Vector3(-200, 30, -100)
	Light(9).Ambient = DXColor(1, 0, 1, 1)
	Light(9).diffuse = DXColor(1, 0, 1, 1)
	Light(9).Direction = Vector(0, 330, 0)
	Light(9).Attenuation0 = 0
	Light(9).Attenuation1 = 0
	Light(9).Attenuation2 = 0
	Light(9).Range = 30
	LightEngine.CreateLight Light(9), "Light9"
	LightEngine.UpdateLight 9, Light(9)

	Light(10).Type = D3DLIGHT_POINT
	Light(10).Position = Vector3(-200, 30, -125)
	Light(10).Ambient = DXColor(1, 0, 1, 1)
	Light(10).diffuse = DXColor(0, 1, 1, 1)
	Light(10).Direction = Vector(0, 330, 0)
	Light(10).Attenuation0 = 0
	Light(10).Attenuation1 = 0
	Light(10).Attenuation2 = 0
	Light(10).Range = 30
	LightEngine.CreateLight Light(10), "Light10"
	LightEngine.UpdateLight 10, Light(10)

	Light(11).Type = D3DLIGHT_POINT
	Light(11).Position = Vector3(-200, 30, -150)
	Light(11).Ambient = DXColor(1, 1, 0, 1)
	Light(11).diffuse = DXColor(1, 1, 1, 1)
	Light(11).Direction = Vector(0, 330, 0)
	Light(11).Attenuation0 = 0
	Light(11).Attenuation1 = 0
	Light(11).Attenuation2 = 0
	Light(11).Range = 30
	LightEngine.CreateLight Light(11), "Light11"
	LightEngine.UpdateLight 11, Light(11)

	'HypnoRide room light
	Light(12).Type = D3DLIGHT_SPOT
	Light(12).Position = Vector3(150, 310, 0)
	Light(12).Ambient = DXColor(0.8, 0.8, 0.8, 0.8)
	Light(12).diffuse = DXColor(1, 5, 5, 5)
	Light(12).Direction = Vector(0, -1, 0)
	Light(12).Attenuation0 = 0
	Light(12).Attenuation1 = 0.007
	Light(12).Attenuation2 = 0
	Light(12).Range = 1000
	LightEngine.CreateLight Light(12), "Light12"
	LightEngine.UpdateLight 12, Light(12)
*/  
	Room->SetMaterial(pGlobals->GetMat("QuickMAT"), -1);
	HypnoRoom->SetMaterial (pGlobals->GetMat("QuickMAT"), -1);
	HypnoDoor->SetMaterial (pGlobals->GetMat("QuickMAT"), -1);
	Shaft->SetMaterial (pGlobals->GetMat("QuickMAT2"), -1);
	HypnoRide->SetMaterial (pGlobals->GetMat("QuickMAT2"), -1);
	RideCar->SetMaterial (pGlobals->GetMat("QuickMAT"), -1);
	HypnoSpiral->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral2->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral3->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral4->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral5->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral6->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral7->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral8->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral9->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral10->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
	HypnoSpiral11->SetMaterial (pGlobals->GetMat("QuickMat2"), -1);
	Eyes->SetMaterial (pGlobals->GetMat("QuickMat3"), -1);
  
	Room->ComputeNormals;
	HypnoRoom->ComputeNormals;
	HypnoDoor->ComputeNormals;
	Shaft->ComputeNormals;
	HypnoRide->ComputeNormals;
	RideCar->ComputeNormals;
  
	Room->Optimize;
	HypnoRoom->Optimize;
	Shaft->Optimize;
	HypnoRide->Optimize;
  
	HypnoDoor->Enable (tvfalse);

}
